# rsr45-dual-autodiff-x

`rsr45-dual-autodiff-x` is a Python package that provides an efficient and user-friendly implementation of automatic differentiation using dual numbers. The package is optimized with Cython for enhanced performance and is particularly useful for tasks requiring derivatives, such as optimization, machine learning, and numerical simulations.

---

## Features

- **Dual Number Arithmetic**: Supports basic operations like addition, subtraction, multiplication, and division with dual numbers.
- **Mathematical Functions**: Includes trigonometric, exponential, logarithmic, and other advanced functions for dual numbers.
- **Automatic Differentiation**: Computes derivatives automatically as a natural byproduct of dual number operations.
- **Cython Optimization**: Improved performance for computationally intensive tasks.
- **Cross-Version Support**: Compatible with Python 3.10 and 3.11.

---

## Installation

### Using pip
Install the package directly from PyPI:

```bash
pip install rsr45-dual-autodiff-x
```
---

## Usage

### Importing the Package

To use the package:
```python
import dual_autodiff as df
from dual_autodiff.dual import Dual
from dual_autodiff.functions import sin, cos, log
```

### Creating Dual Numbers
```python
x = Dual(2, 1)  # Represents the dual number 2 + 1ε
```

### Performing Operations
```python
# Example: f(x) = log(sin(x)) + x^2 * cos(x)
f_x = log(sin(x)) + x**2 * cos(x)
print(f_x)  # Output the result and its derivative
```

---



